@@ -3,8 +3,8 @@ from functools import partial
 
 #####################
 
-def query(session, query, **kargs):
-    generated_query = generate_query(query, **kargs) 
+def query(session, s, **kargs):
+    generated_query = generate_query(s, **kargs) 
     return partial(wr.athena.read_sql_query,
                    database=kargs.get('db'),
                    boto3_session=session)(generated_query)
